/**
 * Mixin to provide shared functionality needed to update participations
 */
import { updateParticipationStatuses } from "./participationStatus.graphql";
import mutateMixin from "aleksis.core/mixins/mutateMixin.js";
import documentationPartMixin from "../documentation/documentationPartMixin";

export default {
  mixins: [documentationPartMixin, mutateMixin],
  methods: {
    sendToServer(participations, field, value) {
      if (field !== "absenceReason") return;

      this.mutate(
        updateParticipationStatuses,
        {
          input: participations.map((participation) => ({
            id: Object.hasOwn(participation, "id")
              ? participation.id
              : participation,
            absenceReason: value === "present" ? null : value,
          })),
        },
        (storedDocumentations, incomingStatuses) => {
          const documentation = storedDocumentations.find(
            (doc) => doc.id === this.documentation.id,
          );

          incomingStatuses.forEach((newStatus) => {
            const participationStatus = documentation.participations.find(
              (part) => part.id === newStatus.id,
            );
            participationStatus.absenceReason = newStatus.absenceReason;
            participationStatus.isOptimistic = newStatus.isOptimistic;
          });

          return storedDocumentations;
        },
        // {
        //   optimisticResponse: {
        //     updateParticipationStatuses: {
        //       items: [
        //         {
        //           id: participation.id,
        //           isOptimistic: true,
        //           relatedDocumentation: {
        //             id: this.documentation.id,
        //             __typename: "DocumentationType",
        //           },
        //           absenceReason: value === "present" ? null : {
        //             id: value,
        //             name: "",
        //             shortName: "",
        //             __typename: "AbsenceReasonType",
        //           },
        //           __typename: "ParticipationStatusType",
        //         },
        //       ],
        //       __typename: "ParticipationStatusBatchPatchMutation",
        //     },
        //   },
        // },
      );
    },
  },
};
